import unittest
from core.gitCommands import GitCommand as gc


class Test(unittest.TestCase):

    def testExecuteCommand(self):
        print("hello")

    if __name__ == '__main__':
        unittest.main()
